@@ -75,7 +75,7 @@ class _BaseDRIVModelFinal:
                                          self._cov_clip, np.inf)
         return prel_theta + (res_y - prel_theta * res_t) * res_z / clipped_cov, clipped_cov
 
-    def fit(self, Y, T, X=None, W=None, Z=None, nuisances=None, sample_weight=None, sample_var=None):
+    def fit(self, Y, T, X=None, W=None, Z=None, nuisances=None, sample_weight=None, freq_weight=None, sample_var=None):
         self.d_y = Y.shape[1:]
         self.d_t = nuisances[1].shape[1:]
         self.d_z = nuisances[3].shape[1:]
@@ -105,7 +105,8 @@ class _BaseDRIVModelFinal:
             sample_weight = sample_weight * clipped_cov.ravel()**2
         elif self._opt_reweighted:
             sample_weight = clipped_cov.ravel()**2
-        self._model_final.fit(X, theta_dr, **filter_none_kwargs(sample_weight=sample_weight, sample_var=sample_var))
+        self._model_final.fit(X, theta_dr, **filter_none_kwargs(sample_weight=sample_weight,
+                                                                freq_weight=freq_weight, sample_var=sample_var))
 
         return self
 
@@ -114,7 +115,7 @@ class _BaseDRIVModelFinal:
             X = self._featurizer.transform(X)
         return self._model_final.predict(X).reshape((-1,) + self.d_y + self.d_t)
 
-    def score(self, Y, T, X=None, W=None, Z=None, nuisances=None, sample_weight=None, sample_var=None):
+    def score(self, Y, T, X=None, W=None, Z=None, nuisances=None, sample_weight=None):
         theta_dr, clipped_cov = self._effect_estimate(nuisances)
 
         if (X is not None) and (self._featurizer is not None):
@@ -211,7 +212,6 @@ class _BaseDRIV(_OrthoLearner):
                  discrete_treatment=False,
                  categories='auto',
                  cv=2,
-                 n_splits='raise',
                  mc_iters=None,
                  mc_agg='mean',
                  random_state=None):
@@ -224,7 +224,6 @@ class _BaseDRIV(_OrthoLearner):
                          discrete_treatment=discrete_treatment,
                          categories=categories,
                          cv=cv,
-                         n_splits=n_splits,
                          mc_iters=mc_iters,
                          mc_agg=mc_agg,
                          random_state=random_state)
@@ -243,7 +242,7 @@ class _BaseDRIV(_OrthoLearner):
 
     @_deprecate_positional("X, W, and Z should be passed by keyword only. In a future release "
                            "we will disallow passing X, W, and Z by position.", ['X', 'W', 'Z'])
-    def fit(self, Y, T, Z, X=None, W=None, *, sample_weight=None, sample_var=None, groups=None,
+    def fit(self, Y, T, Z, X=None, W=None, *, sample_weight=None, freq_weight=None, sample_var=None, groups=None,
             cache_values=False, inference=None):
         """
         Estimate the counterfactual model from data, i.e. estimates function :math:`\\theta(\\cdot)`.
@@ -260,10 +259,15 @@ class _BaseDRIV(_OrthoLearner):
             Features for each sample
         W: optional(n, d_w) matrix or None (Default=None)
             Controls for each sample
-        sample_weight: optional(n,) vector or None (Default=None)
-            Weights for each samples
-        sample_var: optional(n,) vector or None (Default=None)
-            Sample variance for each sample
+        sample_weight : (n,) array like, default None
+            Individual weights for each sample. If None, it assumes equal weight.
+        freq_weight: (n,) array like of integers, default None
+            Weight for the observation. Observation i is treated as the mean
+            outcome of freq_weight[i] independent observations.
+            When ``sample_var`` is not None, this should be provided.
+        sample_var : {(n,), (n, d_y)} nd array like, default None
+            Variance of the outcome(s) of the original freq_weight[i] observations that were used to
+            compute the mean outcome represented by observation i.
         groups: (n,) vector, optional
             All rows corresponding to the same group will be kept together during splitting.
             If groups is not None, the `cv` argument passed to this class's initializer
@@ -280,7 +284,7 @@ class _BaseDRIV(_OrthoLearner):
         """
         # Replacing fit from _OrthoLearner, to reorder arguments and improve the docstring
         return super().fit(Y, T, X=X, W=W, Z=Z,
-                           sample_weight=sample_weight, sample_var=sample_var, groups=groups,
+                           sample_weight=sample_weight, freq_weight=freq_weight, sample_var=sample_var, groups=groups,
                            cache_values=cache_values, inference=inference)
 
     def score(self, Y, T, Z, X=None, W=None, sample_weight=None):
@@ -425,7 +429,6 @@ class _IntentToTreatDRIV(_BaseDRIV):
                  fit_cate_intercept=True,
                  cov_clip=.1,
                  cv=3,
-                 n_splits='raise',
                  mc_iters=None,
                  mc_agg='mean',
                  opt_reweighted=False,
@@ -442,7 +445,6 @@ class _IntentToTreatDRIV(_BaseDRIV):
                          fit_cate_intercept=fit_cate_intercept,
                          cov_clip=cov_clip,
                          cv=cv,
-                         n_splits=n_splits,
                          mc_iters=mc_iters,
                          mc_agg=mc_agg,
                          discrete_instrument=True,
@@ -560,7 +562,6 @@ class IntentToTreatDRIV(_IntentToTreatDRIV):
                  fit_cate_intercept=True,
                  cov_clip=.1,
                  cv=3,
-                 n_splits='raise',
                  mc_iters=None,
                  mc_agg='mean',
                  opt_reweighted=False,
@@ -575,7 +576,6 @@ class IntentToTreatDRIV(_IntentToTreatDRIV):
                          fit_cate_intercept=fit_cate_intercept,
                          cov_clip=cov_clip,
                          cv=cv,
-                         n_splits=n_splits,
                          mc_iters=mc_iters,
                          mc_agg=mc_agg,
                          opt_reweighted=opt_reweighted,
@@ -599,11 +599,11 @@ class IntentToTreatDRIV(_IntentToTreatDRIV):
 
     @property
     def models_Y_X(self):
-        return [mdl._model_Y_X._model for mdl in super().models_nuisance_]
+        return [[mdl._model_Y_X._model for mdl in mdls] for mdls in super().models_nuisance_]
 
     @property
     def models_T_XZ(self):
-        return [mdl._model_T_XZ._model for mdl in super().models_nuisance_]
+        return [[mdl._model_T_XZ._model for mdl in mdls] for mdls in super().models_nuisance_]
 
     @property
     def nuisance_scores_Y_X(self):
@@ -696,7 +696,6 @@ class LinearIntentToTreatDRIV(StatsModelsCateEstimatorMixin, IntentToTreatDRIV):
                  fit_cate_intercept=True,
                  cov_clip=.1,
                  cv=3,
-                 n_splits='raise',
                  mc_iters=None,
                  mc_agg='mean',
                  categories='auto',
@@ -709,7 +708,6 @@ class LinearIntentToTreatDRIV(StatsModelsCateEstimatorMixin, IntentToTreatDRIV):
                          model_final=None,
                          cov_clip=cov_clip,
                          cv=cv,
-                         n_splits=n_splits,
                          mc_iters=mc_iters,
                          mc_agg=mc_agg,
                          opt_reweighted=False,
@@ -721,7 +719,7 @@ class LinearIntentToTreatDRIV(StatsModelsCateEstimatorMixin, IntentToTreatDRIV):
     # override only so that we can update the docstring to indicate support for `StatsModelsInference`
     @_deprecate_positional("X, W, and Z should be passed by keyword only. In a future release "
                            "we will disallow passing X, W, and Z by position.", ['X', 'W', 'Z'])
-    def fit(self, Y, T, Z, X=None, W=None, *, sample_weight=None, sample_var=None, groups=None,
+    def fit(self, Y, T, Z, X=None, W=None, *, sample_weight=None, groups=None,
             cache_values=False, inference='auto'):
         """
         Estimate the counterfactual model from data, i.e. estimates function :math:`\\theta(\\cdot)`.
@@ -738,10 +736,8 @@ class LinearIntentToTreatDRIV(StatsModelsCateEstimatorMixin, IntentToTreatDRIV):
             Features for each sample
         W: optional(n, d_w) matrix or None (Default=None)
             Controls for each sample
-        sample_weight: optional(n,) vector or None (Default=None)
-            Weights for each samples
-        sample_var: optional(n,) vector or None (Default=None)
-            Sample variance for each sample
+        sample_weight : (n,) array like or None
+            Individual weights for each sample. If None, it assumes equal weight.
         groups: (n,) vector, optional
             All rows corresponding to the same group will be kept together during splitting.
             If groups is not None, the `cv` argument passed to this class's initializer
@@ -757,8 +753,9 @@ class LinearIntentToTreatDRIV(StatsModelsCateEstimatorMixin, IntentToTreatDRIV):
         -------
         self : instance
         """
+        # TODO: do correct adjustment for sample_var
         return super().fit(Y, T, Z=Z, X=X, W=W,
-                           sample_weight=sample_weight, sample_var=sample_var, groups=groups,
+                           sample_weight=sample_weight, groups=groups,
                            cache_values=cache_values, inference=inference)
 
     def refit_final(self, *, inference='auto'):
